Stan Math Library: stan/math/fwd/scal/fun/exp.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

exp.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_SCAL_FUN_EXP_HPP
2 #define STAN_MATH_FWD_SCAL_FUN_EXP_HPP
3
4 #include <stan/math/fwd/core.hpp>
5 #include <cmath>
6
7 namespace stan {
8 namespace math {
9 template <typename T>
10 inline fvar<T> exp(const fvar<T>& x) {
11 using std::exp;
12 return fvar<T>(exp(x.val_), x.d_ * exp(x.val_));
13 }
14
15 }
16 }
17 #endif
core.hpp
stan::math::fvar::d_
T d_
Definition: fvar.hpp:15
stan
Definition: log_sum_exp.hpp:8
stan::math::exp
var exp(const var &a)
Return the exponentiation of the specified variable (cmath).
Definition: exp.hpp:44
stan::math::fvar::val_
T val_
Definition: fvar.hpp:14
stan::math::exp
fvar< T > exp(const fvar< T > &x)
Definition: exp.hpp:10
stan::math::fvar
Definition: fvar.hpp:13

[ Stan Home Page ] © 2011–2016, Stan Development Team.